
        "use strict";

        const conversions = require("webidl-conversions");
        const utils = require("./utils.js");
        
      const Blob = require("./Blob.js");
const implSymbol = utils.implSymbol;
const ctorRegistrySymbol = utils.ctorRegistrySymbol;
const EventTarget = require("./EventTarget.js");

      
      const interfaceName = "FileReader";
    
      exports.is = function is(obj) {
        return utils.isObject(obj) && utils.hasOwn(obj, implSymbol) && obj[implSymbol] instanceof Impl.implementation;
      };
      exports.isImpl = function isImpl(obj) {
        return utils.isObject(obj) && obj instanceof Impl.implementation;
      };
      exports.convert = function convert(obj, { context = "The provided value" } = {}) {
        if (exports.is(obj)) {
          return utils.implForWrapper(obj);
        }
        throw new TypeError(`${context} is not of type 'FileReader'.`);
      };
    
      exports.create = function create(globalObject, constructorArgs, privateData) {
        if (globalObject[ctorRegistrySymbol] === undefined) {
          throw new Error('Internal error: invalid global object');
        }

        const ctor = globalObject[ctorRegistrySymbol]["FileReader"];
        if (ctor === undefined) {
          throw new Error('Internal error: constructor FileReader is not installed on the passed global object');
        }

        let obj = Object.create(ctor.prototype);
        obj = exports.setup(obj, globalObject, constructorArgs, privateData);
        return obj;
      };
      exports.createImpl = function createImpl(globalObject, constructorArgs, privateData) {
        const obj = exports.create(globalObject, constructorArgs, privateData);
        return utils.implForWrapper(obj);
      };
      exports._internalSetup = function _internalSetup(obj, globalObject) {
    
        EventTarget._internalSetup(obj, globalObject);
      
      };
      exports.setup = function setup(obj, globalObject, constructorArgs = [], privateData = {}) {
        privateData.wrapper = obj;

        exports._internalSetup(obj, globalObject);
        Object.defineProperty(obj, implSymbol, {
          value: new Impl.implementation(globalObject, constructorArgs, privateData),
          configurable: true
        });
    
        obj[implSymbol][utils.wrapperSymbol] = obj;
        if (Impl.init) {
          Impl.init(obj[implSymbol], privateData);
        }
        return obj;
      };
    
      exports.install = function install(globalObject) {
    
        if (globalObject.EventTarget === undefined) {
          throw new Error('Internal error: attempting to evaluate FileReader before EventTarget');
        }
      class FileReader extends globalObject.EventTarget {
        constructor() {
        
        return exports.setup(Object.create(new.target.prototype), globalObject, undefined);
      }
      
        readAsArrayBuffer(blob) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        if (!exports.is(esValue)) {
          throw new TypeError("Illegal invocation");
        }
      
        if (arguments.length < 1) {
          throw new TypeError("Failed to execute 'readAsArrayBuffer' on 'FileReader': 1 argument required, but only " + arguments.length +
                              " present.");
        }
      const args = [];{ let curArg = arguments[0];
        curArg = Blob.convert(curArg, { context: "Failed to execute 'readAsArrayBuffer' on 'FileReader': parameter 1", });
      args.push(curArg);}
        return esValue[implSymbol].readAsArrayBuffer(...args);
      }
      
        readAsBinaryString(blob) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        if (!exports.is(esValue)) {
          throw new TypeError("Illegal invocation");
        }
      
        if (arguments.length < 1) {
          throw new TypeError("Failed to execute 'readAsBinaryString' on 'FileReader': 1 argument required, but only " + arguments.length +
                              " present.");
        }
      const args = [];{ let curArg = arguments[0];
        curArg = Blob.convert(curArg, { context: "Failed to execute 'readAsBinaryString' on 'FileReader': parameter 1", });
      args.push(curArg);}
        return esValue[implSymbol].readAsBinaryString(...args);
      }
      
        readAsText(blob) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        if (!exports.is(esValue)) {
          throw new TypeError("Illegal invocation");
        }
      
        if (arguments.length < 1) {
          throw new TypeError("Failed to execute 'readAsText' on 'FileReader': 1 argument required, but only " + arguments.length +
                              " present.");
        }
      const args = [];{ let curArg = arguments[0];
        curArg = Blob.convert(curArg, { context: "Failed to execute 'readAsText' on 'FileReader': parameter 1", });
      args.push(curArg);}{ let curArg = arguments[1];
      if (curArg !== undefined) {
    
        curArg = conversions["DOMString"](curArg, { context: "Failed to execute 'readAsText' on 'FileReader': parameter 2", });
      }args.push(curArg);}
        return esValue[implSymbol].readAsText(...args);
      }
      
        readAsDataURL(blob) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        if (!exports.is(esValue)) {
          throw new TypeError("Illegal invocation");
        }
      
        if (arguments.length < 1) {
          throw new TypeError("Failed to execute 'readAsDataURL' on 'FileReader': 1 argument required, but only " + arguments.length +
                              " present.");
        }
      const args = [];{ let curArg = arguments[0];
        curArg = Blob.convert(curArg, { context: "Failed to execute 'readAsDataURL' on 'FileReader': parameter 1", });
      args.push(curArg);}
        return esValue[implSymbol].readAsDataURL(...args);
      }
      
        abort() {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        if (!exports.is(esValue)) {
          throw new TypeError("Illegal invocation");
        }
      
        return esValue[implSymbol].abort();
      }
      
        get readyState() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return esValue[implSymbol]["readyState"];
    }
      
        get result() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["result"]);
    }
      
        get error() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["error"]);
    }
      
        get onloadstart() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["onloadstart"]);
    }
      
        set onloadstart(V) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
        
      V = utils.tryImplForWrapper(V);
    
        esValue[implSymbol]["onloadstart"] = V;
      }
      
        get onprogress() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["onprogress"]);
    }
      
        set onprogress(V) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
        
      V = utils.tryImplForWrapper(V);
    
        esValue[implSymbol]["onprogress"] = V;
      }
      
        get onload() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["onload"]);
    }
      
        set onload(V) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
        
      V = utils.tryImplForWrapper(V);
    
        esValue[implSymbol]["onload"] = V;
      }
      
        get onabort() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["onabort"]);
    }
      
        set onabort(V) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
        
      V = utils.tryImplForWrapper(V);
    
        esValue[implSymbol]["onabort"] = V;
      }
      
        get onerror() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["onerror"]);
    }
      
        set onerror(V) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
        
      V = utils.tryImplForWrapper(V);
    
        esValue[implSymbol]["onerror"] = V;
      }
      
        get onloadend() {
      const esValue = this !== null && this !== undefined ? this : globalObject;
      
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
      return utils.tryWrapperForImpl(esValue[implSymbol]["onloadend"]);
    }
      
        set onloadend(V) {
        const esValue = this !== null && this !== undefined ? this : globalObject;
        
      if (!exports.is(esValue)) {
        throw new TypeError("Illegal invocation");
      }
    
        
      V = utils.tryImplForWrapper(V);
    
        esValue[implSymbol]["onloadend"] = V;
      }
      }Object.defineProperties(FileReader.prototype, { readAsArrayBuffer: { enumerable: true }, readAsBinaryString: { enumerable: true }, readAsText: { enumerable: true }, readAsDataURL: { enumerable: true }, abort: { enumerable: true }, readyState: { enumerable: true }, result: { enumerable: true }, error: { enumerable: true }, onloadstart: { enumerable: true }, onprogress: { enumerable: true }, onload: { enumerable: true }, onabort: { enumerable: true }, onerror: { enumerable: true }, onloadend: { enumerable: true }, [Symbol.toStringTag]: { value: "FileReader", configurable: true }, EMPTY: { value: 0, enumerable: true }, LOADING: { value: 1, enumerable: true }, DONE: { value: 2, enumerable: true } });Object.defineProperties(FileReader, { EMPTY: { value: 0, enumerable: true }, LOADING: { value: 1, enumerable: true }, DONE: { value: 2, enumerable: true } });
        if (globalObject[ctorRegistrySymbol] === undefined) {
          globalObject[ctorRegistrySymbol] = Object.create(null);
        }
        globalObject[ctorRegistrySymbol][interfaceName] = FileReader;

        Object.defineProperty(globalObject, interfaceName, {
          configurable: true,
          writable: true,
          value: FileReader
        });
      };
    
    
        const Impl = require("../file-api/FileReader-impl.js");
      